@@ -83,7 +83,6 @@ def __request(method, url, params = {}, headers ={}, auth = None, callback = Non
         req = urllib2.Request(url, data, headers)
         req.get_method = lambda: method
         try:
-            print "Timeout is " + str(_timeout) + "s"
             response = urllib2.urlopen(req, timeout=_timeout)
         except urllib2.HTTPError, e:
             response = e
@@ -165,8 +164,8 @@ def get(url, **kwargs):
             url += "?"
         else:
             url += "&"
-        url += urllib.urlencode(params)
-
+        url += urllib.urlencode(dict((k, v) for k, v in params.iteritems() if v is not None)) # Removing None values
+        
     return __dorequest("GET", url, {}, kwargs.get(HEADERS_KEY, {}), kwargs.get(AUTH_KEY, None), kwargs.get(CALLBACK_KEY, None))
     
 def post(url, **kwargs):
